Change Password
===============
App for a user who wants to change their password.

Flow
====
1. Navigate to teh change password page
2. User enters old password, new password and confirms new password.
3. On validation success, user is redirected to a "change password success" page alerting the user their password has been successfully updated.